@@ -12,7 +12,8 @@ class AppHookConfig(models.Model):
     concrete model
     """
     type = models.CharField(_('type'), max_length=100)
-    namespace = models.CharField(_(u'instance namespace'), default=None, max_length=100)
+    namespace = models.CharField(
+        _(u'instance namespace'), default=None, max_length=100, unique=True)
     app_data = AppDataField()
 
     cmsapp = None
@@ -44,4 +45,4 @@ class AppHookConfig(models.Model):
         try:
             return getattr(self.app_data.config, item)
         except:
-            raise AttributeError('attribute %s not found' % item)
+            raise AttributeError('attribute %s not found' % item)
\ No newline at end of file
